==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/gw_friends.js <==
function gw_friends(){};

var _me = gw_friends.prototype;

//********************************************************************************
//Základní GET funkce pro práci s gw_friends
//********************************************************************************
//Vstup:  sDataSet ... globální pole, kde jsou uloženy všechny resource
//Výstup: pole asociativních polí
//********************************************************************************

_me.get = function(sDataSet)
{
  //Zadali jsem parametr?
	if (!sDataSet)
	  return false;
	  
	var aFriends = dataSet.get(sDataSet,['GW_FRIENDS']);

	//Je tento resource inicializovaný?
	if (typeof aFriends != 'object')
	  return false;

	var aFriendFrame;
	var aResult = [];
	var aFriendResult;
	
	//Procházíme jednotlivé friend
	for(var n in aFriends['ITEMS'])
	{
		aFriendFrame = aFriends['ITEMS'][n];
		aFriendResult = {};
	  aFriendResult['UID'] = aFriendFrame['ATTRIBUTES']['UID'];

    //Procházíme jednotlivé hodnoty friend
		for(var sValue in aFriendFrame['VALUES'])
		  aFriendResult[sValue] = aFriendFrame['VALUES'][sValue]['VALUE'];
		  
		aResult.push(aFriendResult);
 	}
	return aResult;
};

//********************************************************************************
//Základní SET funkce pro práci s gw_friends
//********************************************************************************
//Vstup: aFriendsInfo ... pole asociativních polí klíč -> hodnota
//       sDataSet     ... globální pole, kam se ukládají všechny resource
//********************************************************************************

_me.set = function(aFriendsInfo,sDataSet)
{
	//Zadali jsme oba parametry?
	if (typeof aFriendsInfo != 'object' || !sDataSet)
	  return false;

	var aFriends = dataSet.get(sDataSet,['GW_FRIENDS']);

  //Je tento resource inicializovaný?
	if (typeof aFriends != 'object')
		return false;

	var aFriend,aItem,aValues;
	var aFriendInfo,sUId;
	var bChange = false;
	var bValuesChanged;
	
	//Procházíme poslané friends
	for(var n in aFriendsInfo)
	{
		aFriendInfo = aFriendsInfo[n];
		sUId = aFriendsInfo[n]['uid'];
	
		//Měníme či přidáváme friend
		if (sUId)
		{
			//Procházíme stávající friends
			for(var m in aFriends['ITEMS'])
			{
				aFriend = aFriends['ITEMS'][m];
				
				//Nalezli jsme odpovídající friend
				if (sUId == aFriend['ATTRIBUTES']['UID'])
				{
          bValuesChanged = false;

					//Aktualizujeme nebo mažeme friend?
					if (count(aFriendInfo) > 1)
					{
						aValues = aFriend['VALUES'];
						
						//Procházíme poslané hodnoty friend
						for(var sValue in aFriendInfo)
							if (sValue != 'uid')
							{
								var sUCValue = sValue.toUpperCase();

								//Máme hodnotu inicializovanou?
								if (typeof aValues[sUCValue] != 'object')
						  		aValues[sUCValue] = {'VALUE':'','ATTRIBUTES':{}};

            		//Změnili jsme hodnotu?
								if (aValues[sUCValue]['VALUE'] != aFriendInfo[sValue])
								{
									aValues[sUCValue]['VALUE'] = aFriendInfo[sValue];
									bValuesChanged = true;
								}
							}
      		}
		 			else
		 			{
						//Mažeme friend
						aFriend['VALUES'] = {};
						bValuesChanged = true;
					}
					
					//Změnili jsme friend?
					if (bValuesChanged)
					{
					  aFriend['ATTRIBUTES']['DONT_SEND'] = false;
						bChange = true;
					}
					break;
				}
			}
		}
		else
		{
			//Přidáváme nového friend
			aItem = {'ATTRIBUTES':{'DONT_SEND':false},'VALUES':{}};
			aValues = aItem['VALUES'];
			
			//Procházíme jednotlivé hodnoty friend
			for(var sValue in aFriendInfo)
				aValues[sValue.toUpperCase()] = {'VALUE':aFriendInfo[sValue],'ATTRIBUTES':{}};

			aFriends['ITEMS'].push(aItem);
			bChange = true;
		}
	}
  //Máme nějaké změny?
	if (bChange)
	{
	  aFriends['ATTRIBUTES']['DONT_SEND'] = false;
	  dataSet.add(sDataSet,['GW_FRIENDS'],aFriends);
	}
	return true;
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/gw_friends.js <==
function gw_friends(){};

var _me = gw_friends.prototype;

//********************************************************************************
//Základní GET funkce pro práci s gw_friends
//********************************************************************************
//Vstup:  sDataSet ... globální pole, kde jsou uloženy všechny resource
//Výstup: pole asociativních polí
//********************************************************************************

_me.get = function(sDataSet)
{
	//Zadali jsem parametr?
	if (!sDataSet)
		return false;

	var aFriends = dataSet.get(sDataSet,['GW_FRIENDS']);

	//Je tento resource inicializovaný?
	if (typeof aFriends != 'object')
		return false;

	var aFriendFrame;
	var aResult = [];
	var aFriendResult;

	//Procházíme jednotlivé friend
	for(var n in aFriends['ITEMS'])
	{
		aFriendFrame = aFriends['ITEMS'][n];
		aFriendResult = {};
		aFriendResult['UID'] = aFriendFrame['ATTRIBUTES']['UID'];

		//Procházíme jednotlivé hodnoty friend
		for(var sValue in aFriendFrame['VALUES'])
			aFriendResult[sValue] = aFriendFrame['VALUES'][sValue]['VALUE'];

		aResult.push(aFriendResult);
	}
	return aResult;
};

//********************************************************************************
//Základní SET funkce pro práci s gw_friends
//********************************************************************************
//Vstup: aFriendsInfo ... pole asociativních polí klíč -> hodnota
//       sDataSet     ... globální pole, kam se ukládají všechny resource
//********************************************************************************

_me.set = function(aFriendsInfo,sDataSet)
{
	//Zadali jsme oba parametry?
	if (typeof aFriendsInfo != 'object' || !sDataSet)
		return false;

	var aFriends = dataSet.get(sDataSet,['GW_FRIENDS']);

	//Je tento resource inicializovaný?
	if (typeof aFriends != 'object')
		return false;

	var aFriend,aItem,aValues;
	var aFriendInfo,sUId;
	var bChange = false;
	var bValuesChanged;

	//Procházíme poslané friends
	for(var n in aFriendsInfo)
	{
		aFriendInfo = aFriendsInfo[n];

		//Měníme či přidáváme friend
		if ((sUId = aFriendsInfo[n]['uid']))
		{
			//Procházíme stávající friends
			for(var m in aFriends['ITEMS'])
			{
				aFriend = aFriends['ITEMS'][m];

				//Nalezli jsme odpovídající friend
				if (sUId == aFriend['ATTRIBUTES']['UID'])
				{
					bValuesChanged = false;

					//Aktualizujeme nebo mažeme friend?
					if (count(aFriendInfo) > 1)
					{
						aValues = aFriend['VALUES'];
						
						//Procházíme poslané hodnoty friend
						for(var sValue in aFriendInfo)
							if (sValue != 'uid')
							{
								var sUCValue = sValue.toUpperCase();

								//Máme hodnotu inicializovanou?
								if (typeof aValues[sUCValue] != 'object')
									aValues[sUCValue] = {'VALUE':'','ATTRIBUTES':{}};

								//Změnili jsme hodnotu?
								if (aValues[sUCValue]['VALUE'] != aFriendInfo[sValue]){
									aValues[sUCValue]['VALUE'] = aFriendInfo[sValue];
									bValuesChanged = true;
								}
							}
					}
					else
					{
						//Mažeme friend
						aFriend['VALUES'] = {};
						bValuesChanged = true;
					}

					//Změnili jsme friend?
					if (bValuesChanged)
					{
						aFriend['ATTRIBUTES']['DONT_SEND'] = false;
						bChange = true;
					}
					break;
				}
			}
		}
		else
		{
			//Přidáváme nového friend
			aItem = {'ATTRIBUTES':{'DONT_SEND':false},'VALUES':{}};
			aValues = aItem['VALUES'];

			//Procházíme jednotlivé hodnoty friend
			for(var sValue in aFriendInfo)
				aValues[sValue.toUpperCase()] = {'VALUE':aFriendInfo[sValue],'ATTRIBUTES':{}};

			aFriends['ITEMS'].push(aItem);
			bChange = true;
		}
	}


	//Máme nějaké změny?
	if (bChange)
	{
		aFriends['ATTRIBUTES']['DONT_SEND'] = false;
		dataSet.add(sDataSet,['GW_FRIENDS'],aFriends);
	}
	return true;
};
